@@ -41,8 +41,6 @@ import com.sencha.gxt.data.shared.loader.ListLoader;
 import com.sencha.gxt.data.shared.loader.LoadResultListStoreBinding;
 import com.sencha.gxt.widget.core.client.ContentPanel;
 import com.sencha.gxt.widget.core.client.Dialog.PredefinedButton;
-import com.sencha.gxt.widget.core.client.Resizable;
-import com.sencha.gxt.widget.core.client.Resizable.Dir;
 import com.sencha.gxt.widget.core.client.box.AlertMessageBox;
 import com.sencha.gxt.widget.core.client.box.ConfirmMessageBox;
 import com.sencha.gxt.widget.core.client.button.TextButton;
@@ -118,7 +116,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 
 	protected void init() {
 		setHeaderVisible(false);
-		new Resizable(this, Dir.E, Dir.SE, Dir.S);
+		//new Resizable(this, Dir.E, Dir.SE, Dir.S);
 
 	}
 
